"""
Classes for dealing with biological sequences. See `core` for the abstract
sequence classes and `nib` and `qdna` for specifics of various
formats.
"""

from bx.seq.core import *  # noqa: F40
